/*----------------------------------------------------------------------------
 * Name:    Blinky.c
 * Purpose: LED Flasher
 * Note(s): Blinky example for XMC4300
 *----------------------------------------------------------------------------
 * Blink LED connected with P1.0, P1.1
 * XMC4300 Relax kit
 *
 *----------------------------------------------------------------------------*/

#include <stdio.h>
#include <XMC4300.h>

const unsigned long led_mask[2] = {1UL << 0, 1UL << 1};      /*  GPIO P1.0, GPIO P1.1       */

void LED_Init(void);
void LED_On  (void);
void LED_Off (void);


volatile uint32_t msTicks;                      /* counts 1ms timeTicks       */
/*----------------------------------------------------------------------------
  SysTick_Handler
 *----------------------------------------------------------------------------*/
void SysTick_Handler(void) {
  msTicks++;
}

/*----------------------------------------------------------------------------
  delays number of tick Systicks (happens every 1 ms)
 *----------------------------------------------------------------------------*/
void Delay (uint32_t dlyTicks) {
  uint32_t curTicks;

  curTicks = msTicks;
  while ((msTicks - curTicks) < dlyTicks) { __NOP(); }
}


/*----------------------------------------------------------------------------
  MAIN function
 *----------------------------------------------------------------------------*/
int main (void) {

  SystemCoreClockUpdate();                      /* update SystemCoreClock     */
  if (SysTick_Config(SystemCoreClock / 1000)) { /* SysTick 1 msec interrupts  */
    while (1) __NOP();                          /* Capture error              */
  }

  LED_Init();

  while(1) {                                 /* Loop forever      */

    LED_On ();                               /* Turn on LED'         */
    Delay(500);                              /* Delay 500ms       */
    LED_Off();                               /* Turn off LED '       */
    Delay(500);                              /* Delay 500ms       */

  }

}

/*----------------------------------------------------------------------------
  initialize LED Pins
 *----------------------------------------------------------------------------*/
void LED_Init (void) {

  /* configure PORT P3.9 pin as output */
  PORT1->IOCR0  &=  ~(0xFFUL << 0);          /* clear P1.0 settings           */
  PORT1->IOCR0  |=   (0x80UL << 0);          /* P1.0 output push pull         */
  PORT1->PDR0   &=  ~(0x07UL << 0);          /* clear P1.0 output settings    */
  PORT1->PDR0   |=   (0x02UL << 0);          /* P1.0 output strong            */

  PORT1->IOCR0  &=  ~(0xFFUL << 8);          /* clear P1.1 settings           */
  PORT1->IOCR0  |=   (0x80UL << 8);          /* P1.1 output push pull         */
  PORT1->PDR0   &=  ~(0x07UL << 4);          /* clear P1.1 output settings    */
  PORT1->PDR0   |=   (0x02UL << 4);          /* P1.1 output strong            */

  LED_Off ();                               /* switch LEDs off               */

}


/*----------------------------------------------------------------------------
  Function that turns on requested LED
 *----------------------------------------------------------------------------*/
void LED_On () {

    PORT1->OMR = led_mask[0] ;  //P1.0
    PORT1->OMR = led_mask[1] ;  //P1.1

}

/*----------------------------------------------------------------------------
  Function that turns off requested LED
 *----------------------------------------------------------------------------*/
void LED_Off () {

    PORT1->OMR = (led_mask[0] << 16);  //P1.0
    PORT1->OMR = (led_mask[1] << 16);  //P1.1


}


