/******************************************************************************
 *
 * Copyright (C) 2013 Infineon Technologies AG. All rights reserved.
 *
 * Infineon Technologies AG (Infineon) is supplying this software for use with
 * Infineon's microcontrollers.
 * This file can be freely distributed within development tools that are
 * supporting such microcontrollers.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS".  NO WARRANTIES, WHETHER EXPRESS, IMPLIED
 * OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE.
 * INFINEON SHALL NOT, IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL,
 * OR CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *
********************************************************************************
**                                                                            **
**                                                                            **
** PLATFORM : Infineon XMC4000 Series                                         **
**                                                                            **
** COMPILER : Compiler Independent                                            **
**                                                                            **
** AUTHOR   : App Developer                                                   **
**                                                                            **
** MAY BE CHANGED BY USER [Yes/No]: Yes                                       **
**                                                                            **
** MODIFICATION DATE : Aug 21, 2013                                           **
**                                                                            **
*******************************************************************************/

/*******************************************************************************
**                       Author(s) Identity                                   **
********************************************************************************
**                                                                            **
** Initials     Name            App Version    Date                           **
** ---------------------------------------------------------------------------**
**   ES      App Developer      1.0.34        21/08/2013                      **
*******************************************************************************/

/**
 * @file CLK001_Const.h
 *
 * @brief  This file contains constants, enumerations and macro constants
 *
 * Revision History
 * 21 Aug 2013   v1.0.33    Static and configuration code separated.
 */

#ifndef CLK001_CONST_H_
#define CLK001_CONST_H_

/* Support for C++ codebase */
#ifdef __cplusplus
extern "C" {
#endif

/*******************************************************************************
**                           Include Files                                    **
*******************************************************************************/

/*******************************************************************************
**                      Global Macro Definitions                               **
*******************************************************************************/

/*********************************************************/
/* PLL Clock Source Options */
/*********************************************************/
/* External Crystal High Precision Oscillator (OSC_HP) */
#define	CLK001_CLOCK_CRYSTAL  1UL
/* External Clock via CLKIN Pin */
#define	CLK001_CLOCK_EXT_CLOCK  2UL
/* Internal Backup Clock */
#define	CLK001_CLOCK_BACK_UP_CLOCK  3UL

/*********************************************************/
/* System Clock Source Options */
/*********************************************************/
/* Main PLL Clock */
#define	CLK001_CLOCK_SRC_PLL  1UL
/* Internal Backup Clock */
#define	CLK001_CLOCK_SRC_BACKUP  2UL

/*********************************************************/
/* PLL Operating Mode Options */
/*********************************************************/
/* Normal Mode */
#define	CLK001_CLOCK_PLL_NORMAL  1UL
/* Prescaler Mode */
#define	CLK001_CLOCK_PLL_PRESCALER  2UL

/*********************************************************/
/* Standby Clock Source Options */
/*********************************************************/
/* Internal Slow Clock (OSC_SI) */
#define	CLK001_HIB_CLOCK_FOSI  1UL
/* Ultra Low Power Oscillator (OSC_ULP) */
#define	CLK001_HIB_CLOCK_OSCULP  2UL

/*********************************************************/
/* RTC Clock Source Options */
/*********************************************************/
/* Internal Slow Clock (OSC_SI - 32KHz) */
#define	CLK001_RTC_CLOCK_FOSI  1UL
/* Ultra Low Power Oscillator (OSC_ULP - 32KHz external crystal) */
#define	CLK001_RTC_CLOCK_OSCULP  2UL

/*********************************************************/
/* Backup Clock Trimming Options */
/*********************************************************/
/* Backup Clock Factory Calibrated */
#define	CLK001_CLOCK_TRIM_FACTORY  1UL
/* Backup Clock Automatic Adjustment */
#define	CLK001_CLOCK_TRIM_AUTOMATIC  2UL

/*********************************************************/
/* Watchdog Clock Source Options */
/*********************************************************/
/* Backup Clock */
#define	CLK001_WDTCLK_BACKUP  0UL
/* Standby Clock */
#define	CLK001_WDTCLK_STANDBY  1UL
/* PLL Clock (fPLL) */
#define	CLK001_WDTCLK_PLL  2U

/*********************************************************/
/* External Clock Source Options */
/*********************************************************/
/* System Clock (fSYS) */
#define	CLK001_EXTCLK_SYSTEM_CLOCK  0UL
/* USB Clock (fUSB) */
#define	CLK001_EXTCLK_USB_CLOCK  2UL
/* PLL Clock (fPLL) */
#define	CLK001_EXTCLK_PLL_CLOCK  3UL


/* Support for C++ codebase */
#ifdef __cplusplus
}
#endif   


#endif /* CLK001_CONST_H_ */
/*CODE_BLOCK_END*/

