/*----------------------------------------------------------------------------
 * Name:    Blinky.c
 * Purpose: LED Flasher
 * Note(s): Blinky example for XMC4700
 *----------------------------------------------------------------------------
 * Blink LED1 (P5.9) und LED2 (P5.8)
 * XMC4700 Relax Kit board
 *
 *----------------------------------------------------------------------------*/

#include <stdio.h>
#include <XMC4700.h>
#include "GPIO.h"



volatile uint32_t msTicks;                      /* counts 1ms timeTicks       */
/*----------------------------------------------------------------------------
  SysTick_Handler
 *----------------------------------------------------------------------------*/
void SysTick_Handler(void) {
  msTicks++;
}

/*----------------------------------------------------------------------------
  delays number of tick Systicks (happens every 1 ms)
 *----------------------------------------------------------------------------*/
void Delay (uint32_t dlyTicks) {
  uint32_t curTicks;

  curTicks = msTicks;
  while ((msTicks - curTicks) < dlyTicks) { __NOP(); }
}


/*----------------------------------------------------------------------------
  MAIN function
 *----------------------------------------------------------------------------*/
int main (void) {

  SystemCoreClockUpdate();                      /* update SystemCoreClock     */
  if (SysTick_Config(SystemCoreClock / 1000)) { /* SysTick 1 msec interrupts  */
    while (1) __NOP();                          /* Capture error              */
  }

/* Configure P5.9 (LED1) and P5.8 (LED2) */
// P5.8  and P5.9 are used as GPIO for LED indication. Macros can be found in GPIO.h
	P5_8_set_mode(OUTPUT_PP_GP);
	P5_8_set_driver_strength(STRONG);
	P5_8_reset();
  P5_9_set_mode(OUTPUT_PP_GP);
	P5_9_set_driver_strength(STRONG);
	P5_9_reset();

  while(1) {                                   /* Loop forever      */

    P5_9_set();                                /* Turn on LED1      */
    Delay(250);                                /* Delay 250ms       */
    P5_8_set();                                /* Turn on LED2      */
    Delay(250);                                /* Delay 250ms       */
    P5_9_reset();                              /* Turn off LED1     */
    Delay(250);                                /* Delay 250ms       */
    P5_8_reset();                              /* Turn off LED2     */
  }

}
